@@ -58,8 +58,6 @@ namespace OCC {
 
 Q_LOGGING_CATEGORY(lcEngine, "sync.engine", QtInfoMsg)
 
-bool SyncEngine::s_anySyncRunning = false;
-
 /** When the client touches a file, block change notifications for this duration (ms)
  *
  * On Linux and Windows the file watcher can't distinguish a change that originates
@@ -97,7 +95,7 @@ SyncEngine::SyncEngine(AccountPtr account, const QString &localPath,
     qRegisterMetaType<SyncFileItemPtr>("SyncFileItemPtr");
     qRegisterMetaType<SyncFileItem::Status>("SyncFileItem::Status");
     qRegisterMetaType<SyncFileStatus>("SyncFileStatus");
-    qRegisterMetaType<SyncFileItemVector>("SyncFileItemVector");
+    qRegisterMetaType<SyncFileItemSet>("SyncFileItemSet");
     qRegisterMetaType<SyncFileItem::Direction>("SyncFileItem::Direction");
 
     // Everything in the SyncEngine expects a trailing slash for the localPath.
@@ -114,6 +112,7 @@ SyncEngine::SyncEngine(AccountPtr account, const QString &localPath,
 
 SyncEngine::~SyncEngine()
 {
+    _goingDown = true;
     abort();
     _excludedFiles.reset();
 }
@@ -174,21 +173,24 @@ bool SyncEngine::checkErrorBlacklisting(SyncFileItem &item)
     qCInfo(lcEngine) << "Item is on blacklist: " << entry._file
                      << "retries:" << entry._retryCount
                      << "for another" << waitSeconds << "s";
-
     // We need to indicate that we skip this file due to blacklisting
     // for reporting and for making sure we don't update the blacklist
     // entry yet.
     // Classification is this _instruction and _status
     item._instruction = CSYNC_INSTRUCTION_IGNORE;
-    item._status = SyncFileItem::BlacklistedError;
+    if (entry._errorCategory == SyncJournalErrorBlacklistRecord::Category::LocalSoftError) {
+        item._status = SyncFileItem::SoftError;
+        item._errorString = entry._errorString;
+    } else {
+        item._status = SyncFileItem::BlacklistedError;
 
-    auto waitSecondsStr = Utility::durationToDescriptiveString1(1000 * waitSeconds);
-    item._errorString = tr("%1 (skipped due to earlier error, trying again in %2)").arg(entry._errorString, waitSecondsStr);
+        auto waitSecondsStr = Utility::durationToDescriptiveString1(1000 * waitSeconds);
+        item._errorString = tr("%1 (skipped due to earlier error, trying again in %2)").arg(entry._errorString, waitSecondsStr);
 
-    if (entry._errorCategory == SyncJournalErrorBlacklistRecord::InsufficientRemoteStorage) {
-        slotInsufficientRemoteStorage();
+        if (entry._errorCategory == SyncJournalErrorBlacklistRecord::Category::InsufficientRemoteStorage) {
+            slotInsufficientRemoteStorage();
+        }
     }
-
     return true;
 }
 
@@ -200,11 +202,11 @@ static bool isFileTransferInstruction(SyncInstructions instruction)
         || instruction == CSYNC_INSTRUCTION_TYPE_CHANGE;
 }
 
-void SyncEngine::deleteStaleDownloadInfos(const SyncFileItemVector &syncItems)
+void SyncEngine::deleteStaleDownloadInfos(const SyncFileItemSet &syncItems)
 {
     // Find all downloadinfo paths that we want to preserve.
     QSet<QString> download_file_paths;
-    foreach (const SyncFileItemPtr &it, syncItems) {
+    for (const auto &it : syncItems) {
         if (it->_direction == SyncFileItem::Down
             && it->_type == ItemTypeFile
             && isFileTransferInstruction(it->_instruction)) {
@@ -215,18 +217,18 @@ void SyncEngine::deleteStaleDownloadInfos(const SyncFileItemVector &syncItems)
     // Delete from journal and from filesystem.
     const QVector<SyncJournalDb::DownloadInfo> deleted_infos =
         _journal->getAndDeleteStaleDownloadInfos(download_file_paths);
-    foreach (const SyncJournalDb::DownloadInfo &deleted_info, deleted_infos) {
+    for (const auto &deleted_info : deleted_infos) {
         const QString tmppath = _propagator->fullLocalPath(deleted_info._tmpfile);
         qCInfo(lcEngine) << "Deleting stale temporary file: " << tmppath;
         FileSystem::remove(tmppath);
     }
 }
 
-void SyncEngine::deleteStaleUploadInfos(const SyncFileItemVector &syncItems)
+void SyncEngine::deleteStaleUploadInfos(const SyncFileItemSet &syncItems)
 {
     // Find all blacklisted paths that we want to preserve.
     QSet<QString> upload_file_paths;
-    foreach (const SyncFileItemPtr &it, syncItems) {
+    for (const auto &it : syncItems) {
         if (it->_direction == SyncFileItem::Up
             && it->_type == ItemTypeFile
             && isFileTransferInstruction(it->_instruction)) {
@@ -235,11 +237,11 @@ void SyncEngine::deleteStaleUploadInfos(const SyncFileItemVector &syncItems)
     }
 
     // Delete from journal.
-    auto ids = _journal->deleteStaleUploadInfos(upload_file_paths);
+    const auto &ids = _journal->deleteStaleUploadInfos(upload_file_paths);
 
     // Delete the stales chunk on the server.
     if (account()->capabilities().chunkingNg()) {
-        foreach (uint transferId, ids) {
+        for (auto transferId : ids) {
             if (!transferId)
                 continue; // Was not a chunked upload
             QUrl url = Utility::concatUrlPath(account()->url(), QLatin1String("remote.php/dav/uploads/") + account()->davUser() + QLatin1Char('/') + QString::number(transferId));
@@ -248,11 +250,11 @@ void SyncEngine::deleteStaleUploadInfos(const SyncFileItemVector &syncItems)
     }
 }
 
-void SyncEngine::deleteStaleErrorBlacklistEntries(const SyncFileItemVector &syncItems)
+void SyncEngine::deleteStaleErrorBlacklistEntries(const SyncFileItemSet &syncItems)
 {
     // Find all blacklisted paths that we want to preserve.
     QSet<QString> blacklist_file_paths;
-    foreach (const SyncFileItemPtr &it, syncItems) {
+    for (const auto &it : syncItems) {
         if (it->_hasBlacklistEntry)
             blacklist_file_paths.insert(it->_file);
     }
@@ -266,10 +268,10 @@ void SyncEngine::conflictRecordMaintenance()
     // Remove stale conflict entries from the database
     // by checking which files still exist and removing the
     // missing ones.
-    auto conflictRecordPaths = _journal->conflictRecordPaths();
+    const auto &conflictRecordPaths = _journal->conflictRecordPaths();
     for (const auto &path : conflictRecordPaths) {
         auto fsPath = _propagator->fullLocalPath(QString::fromUtf8(path));
-        if (!QFileInfo(fsPath).exists()) {
+        if (!QFileInfo::exists(fsPath)) {
             _journal->deleteConflictRecord(path);
         }
     }
@@ -279,7 +281,7 @@ void SyncEngine::conflictRecordMaintenance()
     //
     // This happens when the conflicts table is new or when conflict files
     // are downlaoded but the server doesn't send conflict headers.
-    for (const auto &path : _seenConflictFiles) {
+    for (const auto &path : qAsConst(_seenConflictFiles)) {
         OC_ASSERT(Utility::isConflictFile(path));
 
         auto bapath = path.toUtf8();
@@ -306,69 +308,7 @@ void OCC::SyncEngine::slotItemDiscovered(const OCC::SyncFileItemPtr &item)
     if (Utility::isConflictFile(item->_file))
         _seenConflictFiles.insert(item->_file);
     if (item->_instruction == CSYNC_INSTRUCTION_UPDATE_METADATA && !item->isDirectory()) {
-        // For directories, metadata-only updates will be done after all their files are propagated.
-
-        // Update the database now already:  New remote fileid or Etag or RemotePerm
-        // Or for files that were detected as "resolved conflict".
-        // Or a local inode/mtime change
-
-        // In case of "resolved conflict": there should have been a conflict because they
-        // both were new, or both had their local mtime or remote etag modified, but the
-        // size and mtime is the same on the server.  This typically happens when the
-        // database is removed. Nothing will be done for those files, but we still need
-        // to update the database.
-
-        // This metadata update *could* be a propagation job of its own, but since it's
-        // quick to do and we don't want to create a potentially large number of
-        // mini-jobs later on, we just update metadata right now.
-
-        if (item->_direction == SyncFileItem::Down) {
-            QString filePath = _localPath + item->_file;
-
-            // If the 'W' remote permission changed, update the local filesystem
-            SyncJournalFileRecord prev;
-            if (_journal->getFileRecord(item->_file, &prev)
-                && prev.isValid()
-                && prev._remotePerm.hasPermission(RemotePermissions::CanWrite) != item->_remotePerm.hasPermission(RemotePermissions::CanWrite)) {
-                const bool isReadOnly = !item->_remotePerm.isNull() && !item->_remotePerm.hasPermission(RemotePermissions::CanWrite);
-                FileSystem::setFileReadOnlyWeak(filePath, isReadOnly);
-            }
-            auto rec = item->toSyncJournalFileRecordWithInode(filePath);
-            if (rec._checksumHeader.isEmpty())
-                rec._checksumHeader = prev._checksumHeader;
-            rec._serverHasIgnoredFiles |= prev._serverHasIgnoredFiles;
-
-            // Ensure it's a placeholder file on disk
-            if (item->_type == ItemTypeFile) {
-                const auto result = _syncOptions._vfs->convertToPlaceholder(filePath, *item);
-                if (!result) {
-                    item->_instruction = CSYNC_INSTRUCTION_ERROR;
-                    item->_errorString = tr("Could not update file : %1").arg(result.error());
-                    return;
-                }
-            }
-
-            // Update on-disk virtual file metadata
-            if (item->_type == ItemTypeVirtualFile) {
-                auto r = _syncOptions._vfs->updateMetadata(filePath, item->_modtime, item->_size, item->_fileId);
-                if (!r) {
-                    item->_instruction = CSYNC_INSTRUCTION_ERROR;
-                    item->_errorString = tr("Could not update virtual file metadata: %1").arg(r.error());
-                    return;
-                }
-            }
-
-            // Updating the db happens on success
-            _journal->setFileRecord(rec);
-
-            // This might have changed the shared flag, so we must notify SyncFileStatusTracker for example
-            emit itemCompleted(item);
-        } else {
-            // Update only outdated data from the disk.
-            _journal->updateLocalMetadata(item->_file, item->_modtime, item->_size, item->_inode);
-        }
         _hasNoneFiles = true;
-        return;
     } else if (item->_instruction == CSYNC_INSTRUCTION_NONE) {
         _hasNoneFiles = true;
         if (_account->capabilities().uploadConflictFiles() && Utility::isConflictFile(item->_file)) {
@@ -398,9 +338,16 @@ void OCC::SyncEngine::slotItemDiscovered(const OCC::SyncFileItemPtr &item)
     checkErrorBlacklisting(*item);
     _needsUpdate = true;
 
-    // Insert sorted
-    auto it = std::lower_bound( _syncItems.begin(), _syncItems.end(), item ); // the _syncItems is sorted
-    _syncItems.insert( it, item );
+    Q_ASSERT([&] {
+        const auto it = _syncItems.find(item);
+        if (it != _syncItems.cend()) {
+            const auto &item2 = it->get();
+            qCWarning(lcEngine) << "We already have an item for " << item2->_file << ":" << item2->_instruction << item2->_direction << "|" << item->_instruction << item->_direction;
+            return false;
+        }
+        return true;
+    }());
+    _syncItems.insert(item);
 
     slotNewItem(item);
 
@@ -411,25 +358,11 @@ void OCC::SyncEngine::slotItemDiscovered(const OCC::SyncFileItemPtr &item)
 
 void SyncEngine::startSync()
 {
-    if (_journal->exists()) {
-        QVector<SyncJournalDb::PollInfo> pollInfos = _journal->getPollInfos();
-        if (!pollInfos.isEmpty()) {
-            qCInfo(lcEngine) << "Finish Poll jobs before starting a sync";
-            CleanupPollsJob *job = new CleanupPollsJob(pollInfos, _account,
-                _journal, _localPath, _syncOptions._vfs, this);
-            connect(job, &CleanupPollsJob::finished, this, &SyncEngine::startSync);
-            connect(job, &CleanupPollsJob::aborted, this, &SyncEngine::slotCleanPollsJobAborted);
-            job->start();
-            return;
-        }
-    }
-
     if (_syncRunning) {
         OC_ASSERT(false);
         return;
     }
 
-    s_anySyncRunning = true;
     _syncRunning = true;
     _anotherSyncNeeded = NoFollowUpSync;
     _clearTouchedFilesTimer.stop();
@@ -440,10 +373,10 @@ void SyncEngine::startSync()
 
     _progressInfo->reset();
 
-    if (!QDir(_localPath).exists()) {
+    if (!QFileInfo::exists(_localPath)) {
         _anotherSyncNeeded = DelayedFollowUp;
         // No _tr, it should only occur in non-mirall
-        syncError(QStringLiteral("Unable to find local sync folder."));
+        Q_EMIT syncError(QStringLiteral("Unable to find local sync folder."));
         finalize(false);
         return;
     }
@@ -456,15 +389,15 @@ void SyncEngine::startSync()
             qCWarning(lcEngine()) << "Too little space available at" << _localPath << ". Have"
                                   << freeBytes << "bytes and require at least" << minFree << "bytes";
             _anotherSyncNeeded = DelayedFollowUp;
-            syncError(tr("Only %1 are available, need at least %2 to start",
+            Q_EMIT syncError(tr("Only %1 are available, need at least %2 to start",
                 "Placeholders are postfixed with file sizes using Utility::octetsToString()")
-                          .arg(
-                              Utility::octetsToString(freeBytes),
-                              Utility::octetsToString(minFree)));
+                                 .arg(
+                                     Utility::octetsToString(freeBytes),
+                                     Utility::octetsToString(minFree)));
             finalize(false);
             return;
         } else {
-            qCInfo(lcEngine) << "There are" << freeBytes << "bytes available at" << _localPath;
+            qCInfo(lcEngine) << "There are" << Utility::octetsToString(freeBytes) << "available at" << _localPath;
         }
     } else {
         qCWarning(lcEngine) << "Could not determine free space available at" << _localPath;
@@ -484,7 +417,7 @@ void SyncEngine::startSync()
     // This creates the DB if it does not exist yet.
     if (!_journal->open()) {
         qCWarning(lcEngine) << "No way to create a sync journal!";
-        syncError(tr("Unable to open or create the local sync database. Make sure you have write access in the sync folder."));
+        Q_EMIT syncError(tr("Unable to open or create the local sync database. Make sure you have write access in the sync folder."));
         finalize(false);
         return;
         // database creation error!
@@ -500,7 +433,7 @@ void SyncEngine::startSync()
     _lastLocalDiscoveryStyle = _localDiscoveryStyle;
 
     if (_syncOptions._vfs->mode() == Vfs::WithSuffix && _syncOptions._vfs->fileSuffix().isEmpty()) {
-        syncError(tr("Using virtual files with suffix, but suffix is not set"));
+        Q_EMIT syncError(tr("Using virtual files with suffix, but suffix is not set"));
         finalize(false);
         return;
     }
@@ -512,7 +445,7 @@ void SyncEngine::startSync()
         qCInfo(lcEngine) << (usingSelectiveSync ? "Using Selective Sync" : "NOT Using Selective Sync");
     } else {
         qCWarning(lcEngine) << "Could not retrieve selective sync list from DB";
-        syncError(tr("Unable to read the blacklist from the local database"));
+        Q_EMIT syncError(tr("Unable to read the blacklist from the local database"));
         finalize(false);
         return;
     }
@@ -527,6 +460,8 @@ void SyncEngine::startSync()
     _progressInfo->_status = ProgressInfo::Discovery;
     emit transmissionProgress(*_progressInfo);
 
+    // TODO: add a constructor to DiscoveryPhase
+    // pass a syncEngine object rather than copying everyhting to another object
     _discoveryPhase.reset(new DiscoveryPhase);
     _discoveryPhase->_account = _account;
     _discoveryPhase->_excludes = _excludedFiles.data();
@@ -543,7 +478,7 @@ void SyncEngine::startSync()
     _discoveryPhase->setSelectiveSyncWhiteList(_journal->getSelectiveSyncList(SyncJournalDb::SelectiveSyncWhiteList, &ok));
     if (!ok) {
         qCWarning(lcEngine) << "Unable to read selective sync list, aborting.";
-        syncError(tr("Unable to read from the sync journal."));
+        Q_EMIT syncError(tr("Unable to read from the sync journal."));
         finalize(false);
         return;
     }
@@ -567,12 +502,16 @@ void SyncEngine::startSync()
     connect(_discoveryPhase.data(), &DiscoveryPhase::itemDiscovered, this, &SyncEngine::slotItemDiscovered);
     connect(_discoveryPhase.data(), &DiscoveryPhase::newBigFolder, this, &SyncEngine::newBigFolder);
     connect(_discoveryPhase.data(), &DiscoveryPhase::fatalError, this, [this](const QString &errorString) {
-        syncError(errorString);
+        Q_EMIT syncError(errorString);
         finalize(false);
     });
     connect(_discoveryPhase.data(), &DiscoveryPhase::finished, this, &SyncEngine::slotDiscoveryFinished);
     connect(_discoveryPhase.data(), &DiscoveryPhase::silentlyExcluded,
         _syncFileStatusTracker.data(), &SyncFileStatusTracker::slotAddSilentlyExcluded);
+    connect(_discoveryPhase.data(), &DiscoveryPhase::excluded,
+        _syncFileStatusTracker.data(), &SyncFileStatusTracker::slotAddSilentlyExcluded);
+    connect(_discoveryPhase.data(), &DiscoveryPhase::excluded,
+        this, &SyncEngine::excluded);
 
     auto discoveryJob = new ProcessDirectoryJob(
         _discoveryPhase.data(), PinState::AlwaysLocal, _discoveryPhase.data());
@@ -601,12 +540,12 @@ void SyncEngine::slotFolderDiscovered(bool local, const QString &folder)
     emit transmissionProgress(*_progressInfo);
 }
 
-void SyncEngine::slotRootEtagReceived(const QString &e)
+void SyncEngine::slotRootEtagReceived(const QByteArray &e, const QDateTime &time)
 {
     if (_remoteRootEtag.isEmpty()) {
         qCDebug(lcEngine) << "Root etag:" << e;
         _remoteRootEtag = e;
-        emit rootEtag(_remoteRootEtag);
+        emit rootEtag(_remoteRootEtag, time);
     }
 }
 
@@ -627,7 +566,7 @@ void SyncEngine::slotDiscoveryFinished()
     // Sanity check
     if (!_journal->open()) {
         qCWarning(lcEngine) << "Bailing out, DB failure";
-        syncError(tr("Cannot open the sync journal"));
+        Q_EMIT syncError(tr("Cannot open the sync journal"));
         finalize(false);
         return;
     } else {
@@ -673,10 +612,22 @@ void SyncEngine::slotDiscoveryFinished()
                     } while (index > 0);
                 }
             }
-            _syncItems.erase(std::remove_if(_syncItems.begin(), _syncItems.end(), [&names](auto i) {
+            //std::erase_if c++20
+            // https://en.cppreference.com/w/cpp/container/set/erase_if
+            const auto erase_if = [](auto &c, const auto &pred) {
+                auto old_size = c.size();
+                for (auto i = c.begin(), last = c.end(); i != last;) {
+                    if (pred(*i)) {
+                        i = c.erase(i);
+                    } else {
+                        ++i;
+                    }
+                }
+                return old_size - c.size();
+            };
+            erase_if(_syncItems, [&names](const SyncFileItemPtr &i) {
                 return !names.contains(QStringRef { &i->_file });
-            }),
-                _syncItems.end());
+            });
         }
 
         qCInfo(lcEngine) << "#### Reconcile (aboutToPropagate) #################################################### " << _stopWatch.addLapTime(QStringLiteral("Reconcile (aboutToPropagate)")) << "ms";
@@ -734,7 +685,7 @@ void SyncEngine::slotDiscoveryFinished()
 
         // Emit the started signal only after the propagator has been set up.
         if (_needsUpdate)
-            emit(started());
+            Q_EMIT started();
 
         _propagator->start(std::move(_syncItems));
 
@@ -744,7 +695,7 @@ void SyncEngine::slotDiscoveryFinished()
     if (!_hasNoneFiles && _hasRemoveFile) {
         qCInfo(lcEngine) << "All the files are going to be changed, asking the user";
         int side = 0; // > 0 means more deleted on the server.  < 0 means more deleted on the client
-        foreach (const auto &it, _syncItems) {
+        for (const auto &it : qAsConst(_syncItems)) {
             if (it->_instruction == CSYNC_INSTRUCTION_REMOVE) {
                 side += it->_direction == SyncFileItem::Down ? 1 : -1;
             }
@@ -773,12 +724,6 @@ void SyncEngine::slotDiscoveryFinished()
     finish();
 }
 
-void SyncEngine::slotCleanPollsJobAborted(const QString &error)
-{
-    syncError(error);
-    finalize(false);
-}
-
 void SyncEngine::setNetworkLimits(int upload, int download)
 {
     _uploadLimit = upload;
@@ -797,6 +742,13 @@ void SyncEngine::setNetworkLimits(int upload, int download)
 
 void SyncEngine::slotItemCompleted(const SyncFileItemPtr &item)
 {
+    Q_ASSERT([&] {
+        // ensure the item is not marked as finished twice
+        const bool finished = item->_finished;
+        item->_finished = true;
+        return !finished;
+    }());
+
     _progressInfo->setProgressComplete(*item);
 
     emit transmissionProgress(*_progressInfo);
@@ -836,7 +788,6 @@ void SyncEngine::finalize(bool success)
     if (_discoveryPhase) {
         _discoveryPhase.take()->deleteLater();
     }
-    s_anySyncRunning = false;
     _syncRunning = false;
     emit finished(success);
 
@@ -861,7 +812,7 @@ void SyncEngine::updateFileTotal(const SyncFileItem &item, qint64 newSize)
     _progressInfo->updateTotalsForFile(item, newSize);
     emit transmissionProgress(*_progressInfo);
 }
-void SyncEngine::restoreOldFiles(SyncFileItemVector &syncItems)
+void SyncEngine::restoreOldFiles(SyncFileItemSet &syncItems)
 {
     /* When the server is trying to send us lots of file in the past, this means that a backup
        was restored in the server.  In that case, we should not simply overwrite the newer file
@@ -898,26 +849,28 @@ void SyncEngine::slotAddTouchedFile(const QString &fn)
 {
     QElapsedTimer now;
     now.start();
-    QString file = QDir::cleanPath(fn);
+    const QString file = QDir::cleanPath(fn);
 
     // Iterate from the oldest and remove anything older than 15 seconds.
     while (true) {
-        auto first = _touchedFiles.begin();
-        if (first == _touchedFiles.end())
+        // don't use a loop as we do erase in here
+        // don't use remove_if as we can stop as soon as we find the first new item
+        auto start = _touchedFiles.cbegin();
+        if (start == _touchedFiles.cend()) {
             break;
+        }
         // Compare to our new QElapsedTimer instead of using elapsed().
         // This avoids querying the current time from the OS for every loop.
-        auto elapsed = std::chrono::milliseconds(now.msecsSinceReference() - first.key().msecsSinceReference());
+        const auto elapsed = std::chrono::milliseconds(now.msecsSinceReference() - start->first.msecsSinceReference());
         if (elapsed <= s_touchedFilesMaxAgeMs) {
             // We found the first path younger than the maximum age, keep the rest.
             break;
         }
-
-        _touchedFiles.erase(first);
+        _touchedFiles.erase(start);
     }
 
     // This should be the largest QElapsedTimer yet, use constEnd() as hint.
-    _touchedFiles.insert(_touchedFiles.constEnd(), now, file);
+    _touchedFiles.insert(_touchedFiles.cend(), { now, file });
 }
 
 void SyncEngine::slotClearTouchedFiles()
@@ -928,10 +881,9 @@ void SyncEngine::slotClearTouchedFiles()
 bool SyncEngine::wasFileTouched(const QString &fn) const
 {
     // Start from the end (most recent) and look for our path. Check the time just in case.
-    auto begin = _touchedFiles.constBegin();
-    for (auto it = _touchedFiles.constEnd(); it != begin; --it) {
-        if ((it-1).value() == fn)
-            return std::chrono::milliseconds((it-1).key().elapsed()) <= s_touchedFilesMaxAgeMs;
+    for (auto it = _touchedFiles.crbegin(); it != _touchedFiles.crend(); ++it) {
+        if (it->second == fn)
+            return std::chrono::milliseconds(it->first.elapsed()) <= s_touchedFilesMaxAgeMs;
     }
     return false;
 }
@@ -1016,7 +968,7 @@ void SyncEngine::wipeVirtualFiles(const QString &localPath, SyncJournalDb &journ
         QString localFile = localPath + QString::fromUtf8(rec._path);
         if (QFile::exists(localFile) && vfs.isDehydratedPlaceholder(localFile)) {
             qCDebug(lcEngine) << "Removing local dehydrated placeholder" << rec._path;
-            QFile::remove(localFile);
+            FileSystem::remove(localFile);
         }
     });
 
@@ -1040,7 +992,9 @@ void SyncEngine::abort()
         disconnect(_discoveryPhase.data(), nullptr, this, nullptr);
         _discoveryPhase.take()->deleteLater();
 
-        syncError(tr("Aborted"));
+        if (!_goingDown) {
+            Q_EMIT syncError(tr("Aborted"));
+        }
         finalize(false);
     }
 }
