@@ -6,7 +6,7 @@
  */
 
 #include <QtTest>
-#include "syncenginetestutils.h"
+#include "testutils/syncenginetestutils.h"
 #include <syncengine.h>
 
 using namespace OCC;
@@ -14,12 +14,14 @@ using namespace OCC;
 bool itemSuccessful(const ItemCompletedSpy &spy, const QString &path, const SyncInstructions instr)
 {
     auto item = spy.findItem(path);
+    Q_ASSERT(item);
     return item->_status == SyncFileItem::Success && item->_instruction == instr;
 }
 
 bool itemConflict(const ItemCompletedSpy &spy, const QString &path)
 {
     auto item = spy.findItem(path);
+    Q_ASSERT(item);
     return item->_status == SyncFileItem::Conflict && item->_instruction == CSYNC_INSTRUCTION_CONFLICT;
 }
 
@@ -45,7 +47,7 @@ bool expectAndWipeConflict(FileModifier &local, FileInfo state, const QString pa
     auto base = state.find(pathComponents.parentDirComponents());
     if (!base)
         return false;
-    for (const auto &item : base->children) {
+    for (const auto &item : qAsConst(base->children)) {
         if (item.name.startsWith(pathComponents.fileName()) && item.name.contains("(conflicted copy")) {
             local.remove(item.path());
             return true;
@@ -79,7 +81,8 @@ private slots:
         QVERIFY(fakeFolder.syncOnce());
 
         // Verify that the conflict names don't have the user name
-        for (const auto &name : findConflicts(fakeFolder.currentLocalState().children["A"])) {
+        const auto &conflicts = findConflicts(fakeFolder.currentLocalState().children["A"]);
+        for (const auto &name : conflicts) {
             QVERIFY(!name.contains(fakeFolder.syncEngine().account()->davDisplayName()));
         }
 
@@ -135,8 +138,8 @@ private slots:
         QCOMPARE(remote.find(conflictMap[a1FileId])->contentChar, 'L');
         QCOMPARE(remote.find("A/a1")->contentChar, 'R');
 
-        QCOMPARE(remote.find(conflictMap[a2FileId])->size, 5);
-        QCOMPARE(remote.find("A/a2")->size, 6);
+        QCOMPARE(remote.find(conflictMap[a2FileId])->contentSize, 5);
+        QCOMPARE(remote.find("A/a2")->contentSize, 6);
     }
 
     void testSeparateUpload()
@@ -205,8 +208,8 @@ private slots:
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
         QCOMPARE(conflictMap.size(), 1);
         QVERIFY(conflictMap.contains(a1ConflictFileId));
-        QCOMPARE(fakeFolder.currentRemoteState().find(conflictName)->size, 66);
-        QCOMPARE(fakeFolder.currentRemoteState().find(conflictMap[a1ConflictFileId])->size, 65);
+        QCOMPARE(fakeFolder.currentRemoteState().find(conflictName)->contentSize, 66);
+        QCOMPARE(fakeFolder.currentRemoteState().find(conflictMap[a1ConflictFileId])->contentSize, 65);
         conflictMap.clear();
     }
 
@@ -296,7 +299,7 @@ private slots:
         fakeFolder.remoteModifier().appendByte("A/a2");
         QVERIFY(fakeFolder.syncOnce());
 
-        auto conflicts = findConflicts(fakeFolder.currentLocalState().children["A"]);
+        const auto &conflicts = findConflicts(fakeFolder.currentLocalState().children["A"]);
         QByteArray a1conflict;
         QByteArray a2conflict;
         for (const auto & conflict : conflicts) {
@@ -439,7 +442,7 @@ private slots:
 
         // 1)
         QVERIFY(itemConflict(completeSpy, "Z"));
-        QCOMPARE(fakeFolder.currentLocalState().find("Z")->size, 63);
+        QCOMPARE(fakeFolder.currentLocalState().find("Z")->contentSize, 63);
         QVERIFY(conflicts[2].contains("Z"));
         QCOMPARE(conflicts[2].toUtf8(), conflictRecords[2]);
         QVERIFY(QFileInfo(fakeFolder.localPath() + conflicts[2]).isDir());
@@ -447,7 +450,7 @@ private slots:
 
         // 2)
         QVERIFY(itemConflict(completeSpy, "A/a1"));
-        QCOMPARE(fakeFolder.currentLocalState().find("A/a1")->size, 5);
+        QCOMPARE(fakeFolder.currentLocalState().find("A/a1")->contentSize, 5);
         QVERIFY(conflicts[0].contains("A/a1"));
         QCOMPARE(conflicts[0].toUtf8(), conflictRecords[0]);
         QVERIFY(QFileInfo(fakeFolder.localPath() + conflicts[0]).isDir());
@@ -455,7 +458,7 @@ private slots:
 
         // 3)
         QVERIFY(itemConflict(completeSpy, "B"));
-        QCOMPARE(fakeFolder.currentLocalState().find("B")->size, 31);
+        QCOMPARE(fakeFolder.currentLocalState().find("B")->contentSize, 31);
         QVERIFY(conflicts[1].contains("B"));
         QCOMPARE(conflicts[1].toUtf8(), conflictRecords[1]);
         QVERIFY(QFileInfo(fakeFolder.localPath() + conflicts[1]).isDir());
@@ -554,7 +557,7 @@ private slots:
         QVERIFY(conflicts.size() == 2);
         QVERIFY(conflicts[0].contains("A (conflicted copy"));
         QVERIFY(conflicts[1].contains("B (conflicted copy"));
-        for (auto conflict : conflicts)
+        for (const auto &conflict : qAsConst(conflicts))
             QDir(fakeFolder.localPath() + conflict).removeRecursively();
         QCOMPARE(fakeFolder.currentLocalState(), fakeFolder.currentRemoteState());
 
@@ -589,10 +592,10 @@ private slots:
 
         // A becomes a conflict because we don't delete folders with files
         // inside of them!
-        auto conflicts = findConflicts(fakeFolder.currentLocalState());
+        const auto &conflicts = findConflicts(fakeFolder.currentLocalState());
         QVERIFY(conflicts.size() == 1);
         QVERIFY(conflicts[0].contains("A (conflicted copy"));
-        for (auto conflict : conflicts)
+        for (const auto &conflict : conflicts)
             QDir(fakeFolder.localPath() + conflict).removeRecursively();
 
         QVERIFY(fakeFolder.syncEngine().isAnotherSyncNeeded() == ImmediateFollowUp);
